package no.ntnu.idatt1002.demo.controller;
import java.io.IOException;
import java.time.LocalDate;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Node;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.DatePicker;
import javafx.scene.control.Label;
import javafx.scene.control.ProgressBar;
import javafx.scene.image.ImageView;
import javafx.scene.paint.Color;
import javafx.scene.text.Text;
import javafx.stage.Stage;
import no.ntnu.idatt1002.demo.data.Economics.ExpenseRegister;
import no.ntnu.idatt1002.demo.data.Economics.FileHandling;
import no.ntnu.idatt1002.demo.data.Economics.IncomeRegister;

/**
 * Class that acts as both a main menu and monthly budget overview that shows the monthly progress of a users account.
 * The main menu act as a hub that branches to numerous other windows, such as adding expenses or looking into food recipes.
 */
public class MainMenuController {

    @FXML
    private Button addExpenseBtn;

    @FXML
    private Button foodButton;

    @FXML
    private Button overviewBtn;

    @FXML
    private ProgressBar progressbar;

    @FXML
    private DatePicker date;

    @FXML
    private ImageView progressMarker;

    @FXML
    private Label today;

    @FXML
    private Text budgetMonth;

    @FXML
    private Label balanceLbl;


    /**
     * Initializes various classes that relates to income and expense, in order to present the overview that depends on the
     * income (money inflow) and expense (money outflow).
     * Sets the progress bar, budget month, balance label, date and how much of the monthly budget has been spent.
     * @throws IOException Upon errors with file reading/writing.
     */
    @FXML
    public void initialize() throws IOException {
        //Instantiate the income- controller and register
        IncomeController incomeController = new IncomeController();
        IncomeRegister incomeRegister = incomeController.loadIncomeDataFromFile("Income");

        //Instantiate the expense- controller and register
        ExpensesController expensesController = new ExpensesController();
        ExpenseRegister expenseRegister = expensesController.loadExpenseDataFromFile("Expense");

        double incomeSum = incomeRegister.getTotalSum();
        double expenseSum = expenseRegister.getTotalSum();

        //Set progress
        progressbar.setProgress(expenseSum/incomeSum);
        //progressMarker.setTranslateX(-275 + progressbar.getProgress());

        //Displaying month
        budgetMonth.setText("BUDGET " + (LocalDate.EPOCH.getMonth()));
        double balance = incomeSum - expenseSum;
        //Set balance
        balanceLbl.setText("Balance: " + (balance));

        //Displaying how much of the monthly budget has been spent.
        today.setText("Used " + expenseSum + " out of " + incomeSum + " this month");

        if (balance < 0) {
            balanceLbl.setTextFill(Color.RED);
        }

        date.setValue(LocalDate.now());
        //date.restrict
    }

    /**
     * Switches scenes from the main menu scene to another, by loading a new FXML file and setting the scene to this location.
     * The destination depends entirely on which button is pressed.
     * @param event A button click.
     * @throws IOException If an error occurs with loading any of the FXML files.
     */
    @FXML
    public void switchScene(ActionEvent event) throws IOException {
        FXMLLoader loader = new FXMLLoader();
        loader.setLocation(SceneController.class.getResource("/view/Budget.fxml"));


        Parent root = loader.load();
        Stage stage = (Stage) ((Node) event.getSource()).getScene().getWindow();
        Scene scene = new Scene(root);
        stage.setScene(scene);
        stage.show();
    }
}
